==> apache-camel-3.4.2-src.zip: apache-camel-3.4.2/components/camel-rabbitmq/src/test/java/org/apache/camel/component/rabbitmq/qpid/RabbitMQConsumerQpidTestReplyTo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.rabbitmq.qpid;

import org.apache.camel.component.rabbitmq.integration.RabbitMQConsumerIntTestReplyTo;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;

public class RabbitMQConsumerQpidTestReplyTo extends RabbitMQConsumerIntTestReplyTo {
    @Override
    public boolean isStartDocker() {
        return false;
    }

    @BeforeClass
    public static void startBroker() throws Exception {
        systemLauncher.startup(createQpidSystemConfig());
    }

    @AfterClass
    public static void stopBroker() {
        systemLauncher.shutdown();
    }

    @Override
    @Before
    public void setUpRabbitMQ() throws Exception {
        super.setUpRabbitMQ();

        channel.queueDeclare(QUEUE, false, false, true, null);
    }
}

==> apache-camel-3.6.0-src.zip: apache-camel-3.6.0/components/camel-rabbitmq/src/test/java/org/apache/camel/component/rabbitmq/qpid/RabbitMQConsumerQpidTestReplyTo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.rabbitmq.qpid;

import org.apache.camel.component.rabbitmq.integration.RabbitMQConsumerIntTestReplyTo;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;

public class RabbitMQConsumerQpidTestReplyTo extends RabbitMQConsumerIntTestReplyTo {
    @Override
    public boolean isStartDocker() {
        return false;
    }

    @BeforeAll
    public static void startBroker() throws Exception {
        systemLauncher.startup(createQpidSystemConfig());
    }

    @AfterAll
    public static void stopBroker() {
        systemLauncher.shutdown();
    }

    @Override
    @BeforeEach
    public void setUpRabbitMQ() throws Exception {
        super.setUpRabbitMQ();

        channel.queueDeclare(QUEUE, false, false, true, null);
    }
}
